# History

## 0.3.0 (2020-07-31)
* changed `askanna artifact` to `askanna artifact add`
* adding `askanna artifact get`
* adding `askanna variable list` to get a list of variables in askanna
* adding `askanna variable change` to modify the value of a variable

## 0.2.0 (2020-07-23)
* adding askanna push -f
* adding askanna push -m "push message"
* changing how .askanna.yml is created
* adding askanna functions for running in job
* adding first test to check on push-target
* download payload with cli


## 0.1.0 (2019-12-05)
* First commit to repo
* Basic function to do askanna login
* First version of askanna package
